# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['dublincore_resource', 'dublincore_resource.migrations']

package_data = \
{'': ['*']}

install_requires = \
['django-controlled-vocabulary>=2.0', 'django>=2.2,<3.0']

setup_kwargs = {
    'name': 'django-dublincore-resource',
    'version': '0.1.1',
    'description': 'Describe your resources with a Dublin Core schema',
    'long_description': "# Django Dublin Core Resource\n\nA Django model and admin interface to manage metadata about your resources\nusing [standard Dublin Core (DC) schema](https://www.dublincore.org/specifications/dublin-core/dcmi-terms/).\n\nThe approach taken by this app is to centralise all your resource metadata\ninto a single table.\n\nMost DC elements accepts only a single value to keep things simple.\n\n# Data Models\n\n* AbstractDublinCoreResource\n  * an abstract Django Model that replicate the Dublin Core schema\n  * each DC element is represented by a field\n  * some DC terms are also included\n  * makes use of ControlledTermField for links to controlled vocabularies\n* DublinCoreResource\n  * inherit from AbstractDublinCoreResource\n* DublinCoreAgent\n  * represents a person or organisation\n* DublinCoreRights\n  * represents Rights statements that can be shared among your resources\n\n# Features\n\n* One centralised table for all your resource\n* Standard Dublin Core elements/fields\n* Lookup values into authority lists / controlled vocabularies\n* Extensible model\n* [TODO] smart bulk import/update from CSV\n* [TODO] advanced input validations\n* [TODO] API / export into various standard formats\n* [TODO] support for file attachment / upload\n* [TODO] support for bibliographic citation parsing / extraction\n* [TODO] support for EDTF dates\n* [TODO] use CC schema for the rights\n\n# Set up\n\n## Installation\n\n```\npip install django-dublincore-resource\n```\n\n```\n./manage.py migrate\n```\n\n## Configuration\n\nThe following settings vars are defined by default but can be overridden\nin your Django settings.py.\n\nBy default this app provides a DublinCoreResource model that inherit\nfrom the abstract AbstractDublinCoreResource model. Set the following to\nFalse to define your own model.\n\n```\n# Set to True to disable the DublinCoreResource model and define your own\nDUBLINCORE_RESOURCE_ABSTRACT_ONLY = False\n```\n\n```\n# The path where resource file are uploaded, relative to your MEDIA path\nDUBLINCORE_RESOURCE_UPLOAD_PATH = 'uploads/dublin_core/'\n```\n",
    'author': 'geoffroy-noel-ddh',
    'author_email': 'geoffroy.noel@kcl.ac.uk',
    'url': 'https://github.com/kingsdigitallab/django-dublincore-resource',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.5,<4.0',
}


setup(**setup_kwargs)
